
API_LOGIN_URL = 'http://api.petkt.com/latest/user/login'
API_DEVICE_URL ='http://api.petkt.com/latest/discovery/device_roster'
API_FEEDERMINI_DEVICE_URL = 'http://api.petkt.com/latest/feedermini/owndevices'
API_FEEDERMINI_HISTORY_URL = 'http://api.petkt.com/latest/feedermini/dailyfeeds'


from datetime import timedelta

class PetKitHistory:
    def __init__(self, history):
        self._history = history

    @property
    def id(self):
        return self._history["id"]

    @property
    def name(self):
        return self._history["name"]

    @property
    def status(self):
        return self._history["status"]

    @property
    def isExecuted(self):
        return self._history["isExecuted"] == 1

    @property
    def time(self):
        return timedelta(seconds=self._history["time"])

    @property
    def realAmount(self):
      if "state" in self._history:
        return timedelta(seconds=self._history["state"]["realAmount"])
      return None

    @property
    def completedAt(self):
      if "state" in self._history:
        return timedelta(seconds=self._history["state"]["completedAt"])
      return None
    
    @property
    def error(self):
      if "state" in self._history:
        return "errCode" in self._history["state"]
      return False



from datetime import timedelta

class PetKitSchedule:
    def __init__(self, schedule):
        self._schedule = schedule

    @property
    def id(self):
        return self._schedule["id"]

    @property
    def name(self):
        return self._schedule["name"]

    @property
    def amount(self):
        return self._schedule["petAmount"][0]["amount"]

    @property
    def time(self):
        return timedelta(seconds=self._schedule["time"])


import hashlib
import json
import logging
import requests
from datetime import datetime, timedelta

from .const import (
    API_LOGIN_URL,
    API_FEEDERMINI_DEVICE_URL
)
from .device import PetKitDevice
from .history import PetKitHistory

_LOGGER = logging.getLogger(__name__)


class PetKitAPI:
    def __init__(self, user, password, access_token=None):
        """ Initialize PetKit API """
        hash = hashlib.md5()
        hash.update(password.encode('utf-8'))
        self._user = user
        self._password = hash.hexdigest()
        self._access_token = access_token
        self._expiration_date = datetime.utcnow()
        self.feeders = {}

    @property
    def is_authorized(self):
        return self._expiration_date < datetime.utcnow()

    def get_all_devices(self):
        """Populate all devices in the PetKit account."""
        result = requests.get(
            API_FEEDERMINI_DEVICE_URL,
            headers={'X-Session': self._access_token}
        )
        try:
            for item in result.json()['result']:
                feeder = PetKitDevice(self._access_token, item)
                self.feeders[feeder.id] = feeder

        except (KeyError, TypeError) as err:
            _LOGGER.error(
                "Error requesting device from PetKit: {}".format(err)
            )

    def request_token(self):
        """Request access and refresh tokens from PetKit."""
        params = {
            "username": self._user,
            "password": self._password,
            "encrypt": 1,
        }

        result = requests.post(API_LOGIN_URL, data=params)
        try:
            createdAt = datetime.strptime(
                result.json()['result']['session']['createdAt'],
                '%Y-%m-%dT%H:%M:%S.%fZ'
            )
            self._access_token = result.json()['result']['session']['id']
            self._expiration_date = createdAt + timedelta(
                seconds=result.json()['result']['session']['expiresIn']
            )
            _LOGGER.debug(
                "Obtained access token {} and expiration datetime {}".format(
                    self._access_token, self._expiration_date
                )
            )
        except (KeyError, TypeError) as err:
            _LOGGER.error("Error requesting token from PetKit: {}".format(err))

    def get_token(self):
      return self._access_token
    
    def getSensors(self):
        return self.feeders


import json
import requests

from datetime import datetime
from .schedule import PetKitSchedule
from .history import PetKitHistory
from .const import *

class PetKitDevice:
    def __init__(self, token, sensor):
      self._access_token = token
      self._sensor = sensor
      self._sensor["schedule"] = {}
      self._sensor["history"] = []
      for sh in sensor["feed"]["items"]:
          shd = PetKitSchedule(sh)
          self._sensor["schedule"][sh["id"]] = shd
      self.get_history(datetime.now().strftime("%Y%m%d"))

    @property
    def id(self):
        return self._sensor["id"]

    @property
    def name(self):
        return self._sensor["name"]

    @property
    def type(self):
        return self._sensor["type"]

    @property
    def batteryPower(self):
        return self._sensor["state"]["batteryPower"]

    @property
    def batteryStatus(self):
        return self._sensor["state"]["batteryStatus"]

    @property
    def desiccantLeftDays(self):
        return self._sensor["state"]["desiccantLeftDays"]

    @property
    def food(self):
        return self._sensor["state"]["food"] == 1

    @property
    def feeding(self):
        return self._sensor["state"]["feeding"] == 1

    @property
    def schedule(self):
        return self._sensor["schedule"]

    @property
    def history(self):
        return self._sensor["history"]

    def get_history(self, day):
        params = {
            "deviceId": self._sensor["id"],
            "days": day
        }
        result = requests.post(
            API_FEEDERMINI_HISTORY_URL,
            data=params,
            headers={'X-Session': self._access_token}
        )
        try:
            for item in result.json()['result']:
                for history in item['items']:
                  self._sensor["history"].append(PetKitHistory(history))

        except (KeyError, TypeError) as err:
            _LOGGER.error(
                "Error requesting history from PetKit: {}".format(err)
            )



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pypetkit",
    version="0.0.1",
    author="CrazYoshi",
    author_email="crazyoshi1186@gmail.com",
    description="PetKit python integration library",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/CrazYoshi/pypetkit",
    packages=setuptools.find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)
